@@ -4,7 +4,7 @@ UNDEFINED = runtime.UNDEFINED
 __M_dict_builtin = dict
 __M_locals_builtin = locals
 _magic_number = 8
-_modified_time = 1336003353.266474
+_modified_time = 1336017512.815094
 _enable_loop = True
 _template_filename = '/mnt/md0/MyWork/MyProjects/PyCK/pyck/forms/templates/form_as_p.mako'
 _template_uri = 'form_as_p.mako'
@@ -76,41 +76,35 @@ def render_body(context,**pageargs):
                 __M_writer(u' ')
                 pass
             # SOURCE LINE 35
-
-            context.write(field().encode("utf-8", errors="ignore"))
-            
-            
-            __M_locals_builtin_stored = __M_locals_builtin()
-            __M_locals.update(__M_dict_builtin([(__M_key, __M_locals_builtin_stored[__M_key]) for __M_key in [] if __M_key in __M_locals_builtin_stored]))
-            # SOURCE LINE 37
+            __M_writer(unicode(field))
             __M_writer(u' ')
-            # SOURCE LINE 38
+            # SOURCE LINE 37
             if 'bottom' == labels_position:
-                # SOURCE LINE 39
+                # SOURCE LINE 38
                 __M_writer(u'<br />')
                 __M_writer(unicode(field.label))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 42
+            # SOURCE LINE 41
             if field_errors and 'bottom'==errors_position:
-                # SOURCE LINE 43
+                # SOURCE LINE 42
                 __M_writer(u'<br />')
                 __M_writer(unicode(field_errors))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 46
+            # SOURCE LINE 45
             if 'right' == labels_position:
-                # SOURCE LINE 47
+                # SOURCE LINE 46
                 __M_writer(unicode(field.label))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 50
+            # SOURCE LINE 49
             if field_errors and 'right'==errors_position:
-                # SOURCE LINE 51
+                # SOURCE LINE 50
                 __M_writer(unicode(field_errors))
                 __M_writer(u' ')
                 pass
-            # SOURCE LINE 53
+            # SOURCE LINE 52
             __M_writer(u'</p>\n')
             pass
         return ''
